Index: content/public/renderer/media_stream_api.h |
diff --git a/content/public/renderer/media_stream_api.h b/content/public/renderer/media_stream_api.h |
index b87c93defb5fc3cea366fb9006cb9686aca258ca..dfb2aaf6ea1161d61c513b8634dedc460f98df54 100644 |
--- a/content/public/renderer/media_stream_api.h |
+++ b/content/public/renderer/media_stream_api.h |
@@ -7,39 +7,47 @@ |
#include "content/common/content_export.h" |
#include "media/base/audio_capturer_source.h" |
-#include "media/base/channel_layout.h" |
#include "media/base/video_capturer_source.h" |
namespace blink { |
class WebMediaStream; |
} |
+namespace media { |
+class AudioParameters; |
+} |
+ |
namespace content { |
// These methods create a WebMediaStreamSource + MediaStreamSource pair with the |
// provided audio or video capturer source. A new WebMediaStreamTrack + |
// MediaStreamTrack pair is created, connected to the source and is plugged into |
// the WebMediaStream (|web_media_stream|). |
// |is_remote| should be true if the source of the data is not a local device. |
// |is_readonly| should be true if the format of the data cannot be changed by |
// MediaTrackConstraints. |
CONTENT_EXPORT bool AddVideoTrackToMediaStream( |
- scoped_ptr<media::VideoCapturerSource> video_source, |
+ scoped_ptr<media::VideoCapturerSource> source, |
bool is_remote, |
bool is_readonly, |
- blink::WebMediaStream* web_media_stream); |
- |
-// |sample_rate|, |channel_layout|, and |frames_per_buffer| specify the audio |
-// parameters of the track. Generally, these should match the |audio_source| so |
-// that it does not have to perform unnecessary sample rate conversion or |
-// channel mixing. |
-CONTENT_EXPORT bool AddAudioTrackToMediaStream( |
- scoped_refptr<media::AudioCapturerSource> audio_source, |
- int sample_rate, |
- media::ChannelLayout channel_layout, |
- int frames_per_buffer, |
+ const std::string& media_stream_url); |
+CONTENT_EXPORT bool AddVideoTrackToMediaStream( |
+ scoped_ptr<media::VideoCapturerSource> source, |
bool is_remote, |
bool is_readonly, |
- blink::WebMediaStream* web_media_stream); |
+ blink::WebMediaStream* web_stream); |
+ |
+CONTENT_EXPORT bool AddAudioTrackToMediaStream( |
+ const scoped_refptr<media::AudioCapturerSource>& source, |
+ const media::AudioParameters& params, |
+ bool is_remote, |
+ bool is_readonly, |
+ const std::string& media_stream_url); |
+CONTENT_EXPORT bool AddAudioTrackToMediaStream( |
+ const scoped_refptr<media::AudioCapturerSource>& source, |
+ bool is_remote, |
+ bool is_readonly, |
+ blink::WebMediaStream* web_stream); |
} // namespace content |
@@ -7,39 +7,47 @@ |
// These methods create a WebMediaStreamSource + MediaStreamSource pair with the |
// provided audio or video capturer source. A new WebMediaStreamTrack + |
-// MediaStreamTrack pair is created, connected to the source and is plugged into |
-// the WebMediaStream (|web_media_stream|). |
+// MediaStreamTrack pair is created, holding the previous MediaStreamSource, and |
+// is plugged into the stream identified by |media_stream_url| (or passed as |
+// |web_stream|). |
// |is_remote| should be true if the source of the data is not a local device. |
// |is_readonly| should be true if the format of the data cannot be changed by |